pub struct Durability {
pub local_sync: SyncPolicy,
pub replica_sync: SyncPolicy,
pub replica_ack: ReplicaAckPolicy,
}Expand description
Durability characteristics for a transaction.
Specifies the durability guarantees associated with a transaction when it’s committed. The durability policy consists of:
- Local sync policy: how the master node synchronizes
- Replica sync policy: how replica nodes synchronize
- Replica acknowledgment policy: how many replicas must acknowledge
Fields
local_sync: SyncPolicySync policy for the local (master) node.
replica_sync: SyncPolicySync policy for replica nodes.
replica_ack: ReplicaAckPolicyAcknowledgment policy for replicas.
Implementations
Sourceimpl Durability
impl Durability
Sourcepub const COMMIT_SYNC: Self
pub const COMMIT_SYNC: Self
Maximum durability: Sync on master and replicas, all replicas acknowledge.
Sourcepub const COMMIT_NO_SYNC: Self
pub const COMMIT_NO_SYNC: Self
No sync on commit, maximum performance.
Sourcepub const COMMIT_WRITE_NO_SYNC: Self
pub const COMMIT_WRITE_NO_SYNC: Self
Write but no sync on commit, good balance of performance and durability.
Sourcepub fn new(
local_sync: SyncPolicy,
replica_sync: SyncPolicy,
replica_ack: ReplicaAckPolicy,
) -> Self
pub fn new( local_sync: SyncPolicy, replica_sync: SyncPolicy, replica_ack: ReplicaAckPolicy, ) -> Self
Creates a new Durability with the specified policies.