pub struct StatsConfig {
pub fast: bool,
pub clear: bool,
}Expand description
Specifies the attributes of a statistics retrieval operation.
Pass to Environment::get_stats or
Database::get_stats.
Defaults
fast = false— collect all statistics, including those that require an expensive action such as a tree traversal or lock-table scan.clear = false— do not reset counters after reading them.
Fields
fast: boolIf true, return only values that do not require expensive actions
(e.g. skip B-tree traversal counts). Implements StatsConfig.setFast(true).
clear: boolIf true, reset all counters to zero after reading them.
Implements StatsConfig.setClear(true).
Implementations
Sourceimpl StatsConfig
impl StatsConfig