pub struct WriteOptions {
pub cache_mode: Option<CacheMode>,
pub ttl: u64,
pub update_ttl: bool,
}Expand description
Options for write operations.
Specifies optional parameters that control write behavior, including caching and time-to-live (TTL) expiration.
Fields
cache_mode: Option<CacheMode>Cache mode for the write operation.
ttl: u64Time-to-live in hours (0 = no expiration).
update_ttl: boolWhether to update TTL on existing records.
Implementations
Sourceimpl WriteOptions
impl WriteOptions
Sourcepub fn with_cache_mode(self, cache_mode: CacheMode) -> Self
pub fn with_cache_mode(self, cache_mode: CacheMode) -> Self
Sets the cache mode.
Sourcepub fn with_update_ttl(self, update_ttl: bool) -> Self
pub fn with_update_ttl(self, update_ttl: bool) -> Self
Sets whether to update TTL on existing records.
Sourcepub fn evict_after_write() -> Self
pub fn evict_after_write() -> Self
Creates WriteOptions with evict-after-write cache mode.
Sourcepub fn with_expiration(ttl_hours: u64) -> Self
pub fn with_expiration(ttl_hours: u64) -> Self
Creates WriteOptions with a TTL.
Sourcepub fn expiration_time_ms(&self, current_time_ms: u64) -> u64
pub fn expiration_time_ms(&self, current_time_ms: u64) -> u64
Returns the expiration time in milliseconds from now, or 0 if no TTL.
Sourcepub fn get_expiration_time(&self) -> u32
pub fn get_expiration_time(&self) -> u32
Returns the packed expiration_time (hours since epoch) for use in BinEntry.
Returns 0 if no TTL is set. Uses noxu_util::ttl_hours_to_expiration
to compute the expiration time relative to now.