CheckpointConfig

Struct CheckpointConfig 

pub struct CheckpointConfig {
    pub force: bool,
    pub k_bytes: u32,
    pub minutes: u32,
    pub minimize_recovery_time: bool,
}
Specifies the attributes of a checkpoint operation invoked via Environment::checkpoint.

Defaults

All thresholds default to 0 (disabled) and force = false. If all thresholds are 0 and force = false, calling checkpoint() still runs a checkpoint subject to normal dirty-node conditions.

Fields

force: bool

If true, force a checkpoint regardless of whether thresholds have been exceeded. Equivalent toCheckpointConfig.setForce(true).

k_bytes: u32

Run a checkpoint if more than this many kibibytes of log data have been written since the last checkpoint. 0 means disabled.

minutes: u32

Run a checkpoint if more than this many minutes have elapsed since the last checkpoint. 0 means disabled.

minimize_recovery_time: bool

If true, perform a full checkpoint that minimises future recovery time (writes all dirty nodes, not just the minimum required).

Implementations

Source

impl CheckpointConfig

pub fn new() -> Self

Creates a CheckpointConfig with all defaults.

pub fn with_force(self, force: bool) -> Self

Builder: set force.

pub fn with_k_bytes(self, k_bytes: u32) -> Self

Builder: set k_bytes threshold.

pub fn with_minutes(self, minutes: u32) -> Self

Builder: set minutes threshold.

pub fn with_minimize_recovery_time(self, minimize: bool) -> Self

Builder: set minimize_recovery_time.