DatabaseEntry

Struct DatabaseEntry 

pub struct DatabaseEntry { /* private fields */ }
Encodes database key and data items as byte arrays.

Both key and data items are represented by DatabaseEntry objects. Key and data byte arrays may refer to arrays of zero length up to arrays of essentially unlimited length.

Internally uses bytes::Bytes so that clone() is O(1) (reference-count increment) and from_vec / set_data_vec are zero-copy.

Implementations

Source

impl DatabaseEntry

pub fn new() -> Self

Creates an empty DatabaseEntry.

pub fn from_bytes(data: &[u8]) -> Self

Creates a DatabaseEntry from a byte slice (copies the slice).

Alias: from_data is also available.

pub fn from_vec(data: Vec<u8>) -> Self

Creates a DatabaseEntry from an owned Vec<u8> — zero-copy.

pub fn from_bytes_ref(data: Bytes) -> Self

Creates a DatabaseEntry from an existing Bytes — zero-copy.

pub fn get_data(&self) -> Option<&[u8]>

Gets a reference to the data.

Returns None if the entry is empty, otherwise returns a slice from offset to offset+size.

pub fn set_data(&mut self, data: &[u8])

Sets the data from a byte slice (copies the slice).

pub fn set_data_vec(&mut self, data: Vec<u8>)

Sets the data from an owned Vec<u8> — zero-copy.

pub fn set_data_bytes(&mut self, data: Bytes)

Sets the data from an existing Bytes — zero-copy.

pub fn from_data(data: &[u8]) -> Self

Creates a DatabaseEntry from a byte slice.

Alias for from_bytes.

pub fn data(&self) -> &[u8]

Gets the data as a byte slice, returning an empty slice if no data.

Convenience method that unwraps the Option from get_data().

pub fn get_size(&self) -> usize

Gets the size of the data.

pub fn set_offset(&mut self, offset: usize)

Sets the offset within the data array.

pub fn get_offset(&self) -> usize

Gets the offset within the data array.

pub fn set_size(&mut self, size: usize)

Sets the size of the data.

pub fn set_partial(&mut self, offset: usize, length: usize, partial: bool)

Configures this entry as a partial entry.

Partial entries are used to read or write only a portion of a record.

pub fn is_partial(&self) -> bool

Returns whether this is a partial entry.

pub fn get_partial_offset(&self) -> usize

Gets the partial offset.

pub fn get_partial_length(&self) -> usize

Gets the partial length.

pub fn clear(&mut self)

Clears the entry, removing all data.

pub fn is_empty(&self) -> bool

Returns true if the entry is empty (has no data).